@@ -1,14 +1,9 @@
 package Tapper::Reports::Receiver;
-# git description: v4.1.2-3-g7874328
+# git description: v4.1.3-3-g76e57b8
 
-BEGIN {
-  $Tapper::Reports::Receiver::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Reports::Receiver::VERSION = '4.1.3';
-}
+our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: Tapper - Receiver for Tapper test reports as TAP or TAP::Archive
-
+$Tapper::Reports::Receiver::VERSION = '5.0.0';
 use 5.010;
 use strict;
 use warnings;
@@ -76,7 +71,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -92,7 +87,7 @@ AMD OSRC Tapper Team <tapper@amd64.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
