@@ -1,11 +1,6 @@
 package Tapper::Reports::Receiver::Daemon;
-BEGIN {
-  $Tapper::Reports::Receiver::Daemon::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Reports::Receiver::Daemon::VERSION = '4.1.3';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Reports::Receiver::Daemon::VERSION = '5.0.0';
 use 5.010;
 
 use strict;
@@ -50,7 +45,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -66,7 +61,7 @@ AMD OSRC Tapper Team <tapper@amd64.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
