@@ -1,11 +1,6 @@
 package Tapper::Reports::Receiver::Level2::Codespeed;
-BEGIN {
-  $Tapper::Reports::Receiver::Level2::Codespeed::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Reports::Receiver::Level2::Codespeed::VERSION = '4.1.3';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Reports::Receiver::Level2::Codespeed::VERSION = '5.0.0';
 use strict;
 use warnings;
 
@@ -48,7 +43,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -114,7 +109,7 @@ AMD OSRC Tapper Team <tapper@amd64.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
